SingleSelection
===============

.. currentmodule:: pykeen.nn.node_piece

.. autoclass:: SingleSelection
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~SingleSelection.__call__
      ~SingleSelection.rank

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: rank
